pub struct Args {Show 15 fields
pub project: String,
pub introduction: String,
pub chain: String,
pub date: String,
pub exploiter_wallet: String,
pub main_attack_contract: String,
pub token_contract: String,
pub attack_transaction: String,
pub unprotected_contract_name: String,
pub vul_contract: String,
pub tx: String,
pub number_of_attacks: String,
pub stolen_money: String,
pub way: String,
pub time: TimeUnit,
}Expand description
Attack Incident Analysis Report Generator
Fields
project: StringSpecify the hacked project name
introduction: StringThe hacked project introduction
chain: StringThe blockchain platform
date: StringThe date the project party stated that it was attacked;
Split by .
exploiter_wallet: StringHacker’s wallet(s);
Split by ,
main_attack_contract: StringMain attack contract(s) address;
Split by ,
token_contract: StringToken contract(s) address;
Split by ,
attack_transaction: StringAttack transaction(s);
Split by ,
unprotected_contract_name: StringVulnerability contract(s) name;
Split by ,
vul_contract: StringVulnerability contract(s) address;
Split by ,
tx: StringTransaction picture(s) path;
Split by ,
number_of_attacks: StringAttack times
stolen_money: StringAttack on Profitable Money
way: StringMain attack way
time: TimeUnitSpecify the time unit, support nanos, micros, millis, secs